Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon EC2 Auto Scaling.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, Resources, and Condition Keys for Amazon EC2 Auto Scaling - AWS Identity and Access Management
Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.

# Actions, Resources, and Condition Keys for Amazon EC2 Auto Scaling

Amazon EC2 Auto Scaling (service prefix: `autoscaling` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by Amazon EC2 Auto Scaling
- Resource Types Defined by Amazon EC2 Auto Scaling
- Condition Keys for Amazon EC2 Auto Scaling

## Actions Defined by Amazon EC2 Auto Scaling

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource Types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table .

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AttachInstances | Attaches one or more EC2 instances to the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
AttachLoadBalancerTargetGroups | Attaches one or more target groups to the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
| autoscaling:TargetGroupARNs |
AttachLoadBalancers | Attaches one or more load balancers to the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
| autoscaling:LoadBalancerNames |
BatchDeleteScheduledAction | Deletes the specified scheduled actions. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
BatchPutScheduledUpdateGroupAction | Creates or updates multiple scheduled scaling actions for an Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
CompleteLifecycleAction | Completes the lifecycle action for the specified token or instance with the specified result. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
CreateAutoScalingGroup | Creates an Auto Scaling group with the specified name and attributes. | Tagging | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
| autoscaling:InstanceTypes autoscaling:LaunchConfigurationName autoscaling:LoadBalancerNames autoscaling:MaxSize autoscaling:MinSize autoscaling:TargetGroupARNs autoscaling:VPCZoneIdentifiers aws:RequestTag/${TagKey} aws:TagKeys |
CreateLaunchConfiguration | Creates a launch configuration. | Write | launchConfiguration* |  |
| autoscaling:ImageId autoscaling:InstanceType autoscaling:SpotPrice |
CreateOrUpdateTags | Creates or updates tags for the specified Auto Scaling group. | Tagging | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteAutoScalingGroup | Deletes the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
DeleteLaunchConfiguration | Deletes the specified launch configuration. | Write | launchConfiguration* |  |
DeleteLifecycleHook | Deletes the specified lifecycle hook. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
DeleteNotificationConfiguration | Deletes the specified notification. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
DeletePolicy | Deletes the specified Auto Scaling policy. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
DeleteScheduledAction | Deletes the specified scheduled action. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
DeleteTags | Deletes the specified tags. | Tagging | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
| aws:RequestTag/${TagKey} aws:TagKeys |
DescribeAccountLimits | Describes the current Auto Scaling resource limits for your AWS account. | List |  |  |
DescribeAdjustmentTypes | Describes the policy adjustment types for use with PutScalingPolicy. | List |  |  |
DescribeAutoScalingGroups | Describes one or more Auto Scaling groups. If a list of names is not provided, the call describes all Auto Scaling groups. | List |  |  |
DescribeAutoScalingInstances | Describes one or more Auto Scaling instances. If a list is not provided, the call describes all instances. | List |  |  |
DescribeAutoScalingNotificationTypes | Describes the notification types that are supported by Auto Scaling. | List |  |  |
DescribeLaunchConfigurations | Describes one or more launch configurations. If you omit the list of names, then the call describes all launch configurations. | List |  |  |
DescribeLifecycleHookTypes | Describes the available types of lifecycle hooks. | List |  |  |
DescribeLifecycleHooks | Describes the lifecycle hooks for the specified Auto Scaling group. | List |  |  |
DescribeLoadBalancerTargetGroups | Describes the target groups for the specified Auto Scaling group. | List |  |  |
DescribeLoadBalancers | Describes the load balancers for the specified Auto Scaling group. | List |  |  |
DescribeMetricCollectionTypes | Describes the available CloudWatch metrics for Auto Scaling. | List |  |  |
DescribeNotificationConfigurations | Describes the notification actions associated with the specified Auto Scaling group. | List |  |  |
DescribePolicies | Describes the policies for the specified Auto Scaling group. | List |  |  |
DescribeScalingActivities | Describes one or more scaling activities for the specified Auto Scaling group. | List |  |  |
DescribeScalingProcessTypes | Describes the scaling process types for use with ResumeProcesses and SuspendProcesses. | List |  |  |
DescribeScheduledActions | Describes the actions scheduled for your Auto Scaling group that haven't run. | List |  |  |
DescribeTags | Describes the specified tags. | Read |  |  |
DescribeTerminationPolicyTypes | Describes the termination policies supported by Auto Scaling. | List |  |  |
DetachInstances | Removes one or more instances from the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
DetachLoadBalancerTargetGroups | Detaches one or more target groups from the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
| autoscaling:TargetGroupARNs |
DetachLoadBalancers | Removes one or more load balancers from the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
| autoscaling:LoadBalancerNames |
DisableMetricsCollection | Disables monitoring of the specified metrics for the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
EnableMetricsCollection | Enables monitoring of the specified metrics for the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
EnterStandby | Moves the specified instances into Standby mode. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
ExecutePolicy | Executes the specified policy. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
ExitStandby | Moves the specified instances out of Standby mode. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
PutLifecycleHook | Creates or updates a lifecycle hook for the specified Auto Scaling Group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
PutNotificationConfiguration | Configures an Auto Scaling group to send notifications when specified events take place. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
PutScalingPolicy | Creates or updates a policy for an Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
PutScheduledUpdateGroupAction | Creates or updates a scheduled scaling action for an Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
| autoscaling:MaxSize autoscaling:MinSize |
RecordLifecycleActionHeartbeat | Records a heartbeat for the lifecycle action associated with the specified token or instance. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
ResumeProcesses | Resumes the specified suspended Auto Scaling processes, or all suspended process, for the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
SetDesiredCapacity | Sets the size of the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
SetInstanceHealth | Sets the health status of the specified instance. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
SetInstanceProtection | Updates the instance protection settings of the specified instances. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
SuspendProcesses | Suspends the specified Auto Scaling processes, or all processes, for the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
TerminateInstanceInAutoScalingGroup | Terminates the specified instance and optionally adjusts the desired group size. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
UpdateAutoScalingGroup | Updates the configuration for the specified Auto Scaling group. | Write | autoScalingGroup* | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey} |
| autoscaling:InstanceTypes autoscaling:LaunchConfigurationName autoscaling:MaxSize autoscaling:MinSize autoscaling:VPCZoneIdentifiers |

## Resource Types Defined by Amazon EC2 Auto Scaling

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table .

Resource Types | ARN | Condition Keys
--- | --- | ---
autoScalingGroup | `arn:$ { Partition}:autoscaling:$ { Region}:$ { Account}:autoScalingGroup:$ { GroupId}:autoScalingGroupName/$ { GroupFriendlyName}` | autoscaling:ResourceTag/${TagKey} aws:ResourceTag/${TagKey}
launchConfiguration | `arn:$ { Partition}:autoscaling:$ { Region}:$ { Account}:launchConfiguration:$ { Id}:launchConfigurationName/$ { LaunchConfigurationName}` |

## Condition Keys for Amazon EC2 Auto Scaling

Amazon EC2 Auto Scaling defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table .

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference .

Condition Keys | Description | Type
--- | --- | ---
autoscaling:ImageId | The AMI used to create the instance. | String
autoscaling:InstanceType | The type of instance, in terms of the hardware resources available. | String
autoscaling:InstanceTypes | The types of instances, in terms of the hardware resources available. | String
autoscaling:LaunchConfigurationName | The name of a launch configuration. | String
autoscaling:LaunchTemplateVersionSpecified | Filters access by whether users can specify any version of a launch template or only the Latest or Default version | Bool
autoscaling:LoadBalancerNames | The name of the load balancer. | String
autoscaling:MaxSize | The maximum scaling size. | Numeric
autoscaling:MinSize | The minimum scaling size. | Numeric
autoscaling:ResourceTag/$ { TagKey} | The value of a tag attached to a resource. | String
autoscaling:SpotPrice | The spot price associated with an instance. | Numeric
autoscaling:TargetGroupARNs | The ARN of a target group. | ARN
autoscaling:VPCZoneIdentifiers | The identifier of a VPC zone. | String
aws:RequestTag/$ { TagKey} | The value of a tag associated with the request. | String
aws:ResourceTag/$ { TagKey} | Filters actions based on tag-value associated with the resource. | String
aws:TagKeys | Filters create requests based on the presence of mandatory tags in the request. | String